Prerequisites:

- Node and NPM

Flow:

- Fork the repository and checkout `master` branch
- Run `npm install` to get or update the dependencies
- Run `npm start` to build `dist/` and `docs/` directories
- Change JavaScript or LESS files in `src/` directories
- Do not commit changes to dist/ or docs/. These will only be built on merge.
- Once finished, submit a [Pull Request](https://github.com/nostalgiaz/bootstrap-switch/compare/master...master). Remember to target `master` as destination branch

Thank you.
